pub struct ProtocolRemoteChatSessionData {
pub session_id: Uuid,
pub expires_at_millis: i64,
pub public_key_bytes: Vec<u8>,
pub key_signature: Vec<u8>,
}Expand description
Network-serializable chat session data.
This is a simplified version that holds raw byte data for transmission. The full version with validated keys lives in steel-core.
Fields
session_id: UuidThe session ID
expires_at_millis: i64When the key expires (as milliseconds since UNIX epoch)
public_key_bytes: Vec<u8>The public key bytes
key_signature: Vec<u8>The key signature bytes
Implementations